@@ -76,7 +76,7 @@ def combine_intermediate_file(intermediate_participant_path, date_in_study):
         df_logs_combined['Local_Timestamp'] = pd.Series(map(converter, df_logs_combined["Local_Time"]))
         df_logs_combined['Date'] = df_logs_combined['Local_Timestamp'].dt.date
     except IndexError:
-        raise Exception("IndexError: list index out of range : " + intermediate_participant_path + sep + date_in_study + str(list(df_logs_combined["Local_Time"])))
+        raise Exception("IndexError: list index out of range (battery_level) : " + intermediate_participant_path + sep + date_in_study + str(list(df_logs_combined["Local_Time"])))
 
     return df_logs_combined
 
