@@ -80,7 +80,7 @@ def combine_intermediate_file(intermediate_participant_path, date_in_study):
     try:
         df_logs_combined['Date'] = df_logs_combined['EVENT_TIME_DATETIME'].dt.date
     except AttributeError:
-        raise Exception("AttributeError (phone lock): " + intermediate_participant_path + date_in_study + df_logs_combined)
+        raise Exception("AttributeError (phone lock): " + intermediate_participant_path + date_in_study)
 
     return df_logs_combined
 
