@@ -160,6 +160,10 @@ def clean_response_files(intermediate_participant_path, date_in_study, participa
     # extract reprompts and treated them as separate prompts
     df_reprompt = extract_reprompt(df_raw)
 
+    if df_reprompt.shape[0] == 0:
+        print("Empty prompt response file after filtering : " + csv_path[0])
+        quit()
+
     # add participant id column
     df_reprompt.insert(loc=0, column='Participant_ID', value=participant_id)
 
